# JSON Schema Store

The largest collection of independent JSON schemas in the world.

[![Build status](https://github.com/SchemaStore/schemastore/actions/workflows/nodejs.yml/badge.svg)](https://github.com/SchemaStore/schemastore/actions/workflows/nodejs.yml)
[![CodeQL](https://github.com/SchemaStore/schemastore/actions/workflows/codeql-analysis.yml/badge.svg)](https://github.com/SchemaStore/schemastore/actions/workflows/codeql-analysis.yml)

The repository is a universal JSON schema store, where schemas for popular JSON documents can be found.

Website: [schemastore.org](https://www.schemastore.org/json/)

## Contribute

Contributions are more than welcome! Both to the website itself or to the various schema files. Please carefully read [CONTRIBUTING.md](./CONTRIBUTING.md).
